@@ -15,6 +15,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with Lightbulb. If not, see <https://www.gnu.org/licenses/>.
+from __future__ import annotations
+
 __all__ = [
     "Check",
     "owner_only",
@@ -31,6 +33,7 @@ __all__ = [
     "bot_has_guild_permissions",
     "bot_has_role_permissions",
     "bot_has_channel_permissions",
+    "has_attachments",
 ]
 
 import functools
@@ -44,7 +47,11 @@ from lightbulb import context as context_
 from lightbulb import errors
 from lightbulb.utils import permissions
 
-T = t.TypeVar("T")
+if t.TYPE_CHECKING:
+    from lightbulb import app
+    from lightbulb import commands
+    from lightbulb import plugins
+
 _CallbackT = t.Union[
     t.Callable[[context_.base.Context], t.Union[bool, t.Coroutine[t.Any, t.Any, bool]]], functools.partial
 ]
@@ -112,7 +119,12 @@ class Check:
         s_callback: t.Optional[_CallbackT] = None,
         m_callback: t.Optional[_CallbackT] = None,
         u_callback: t.Optional[_CallbackT] = None,
-        add_hook: t.Optional[t.Callable[[T], T]] = None,
+        add_hook: t.Optional[
+            t.Callable[
+                [t.Union[plugins.Plugin, app.BotApp, commands.base.CommandLike]],
+                t.Union[plugins.Plugin, app.BotApp, commands.base.CommandLike],
+            ]
+        ] = None,
     ) -> None:
         self.prefix_callback = p_callback
         self.slash_callback = s_callback or p_callback
