@@ -32,6 +32,13 @@ if t.TYPE_CHECKING:
     from lightbulb import commands
     from lightbulb import events
 
+ListenerT = t.TypeVar("ListenerT", bound=t.Callable[..., t.Coroutine[t.Any, t.Any, None]])
+ErrorHandlerT = t.TypeVar(
+    "ErrorHandlerT",
+    bound=t.Callable[..., t.Coroutine[t.Any, t.Any, t.Optional[bool]]],
+)
+RemoveHookT = t.TypeVar("RemoveHookT", bound=t.Callable[..., t.Union[t.Coroutine[t.Any, t.Any, None], None]])
+
 
 class Plugin:
     """
@@ -48,7 +55,7 @@ class Plugin:
     __slots__ = (
         "name",
         "description",
-        "d",
+        "_d",
         "_raw_commands",
         "_all_commands",
         "_listeners",
@@ -63,13 +70,10 @@ class Plugin:
         """The plugin's name."""
         self.description = description or ""
         """The plugin's description."""
-        self.d: t.Optional[data_store.DataStore] = None
-        """A :obj:`~.utils.data_store.DataStore` instance enabling storage of custom data without subclassing.
-        This will be ``None`` unless you explicitly specify you want the data storage instance included by passing
-        in the kwarg ``include_datastore=True`` to the constructor.
-        """
+
+        self._d: t.Optional[data_store.DataStore] = None
         if include_datastore:
-            self.d = data_store.DataStore()
+            self._d = data_store.DataStore()
 
         self._raw_commands: t.List[commands.base.CommandLike] = []
         self._all_commands: t.List[commands.base.Command] = []
@@ -87,8 +91,27 @@ class Plugin:
         self._app: t.Optional[app_.BotApp] = None
 
     @property
-    def app(self) -> t.Optional[app_.BotApp]:
+    def d(self) -> data_store.DataStore:
+        """
+        A :obj:`~.utils.data_store.DataStore` instance enabling storage of custom data without subclassing.
+        This will raise a :obj:`RuntimeError` unless you explicitly specify you want the data
+        storage instance included by passing the kwarg ``include_datastore=True`` to the constructor.
+        """
+        if self._d is None:
+            raise RuntimeError(
+                "'Plugin.d' cannot be accessed unless 'include_datastore=True' was provided during instantiation"
+            )
+
+        return self._d
+
+    @property
+    def app(self) -> app_.BotApp:
         """The :obj:`~.app.BotApp` instance that the plugin is registered to."""
+        if self._app is None:
+            raise RuntimeError(
+                "'Plugin.app' cannot be accessed before the plugin has been added to a 'BotApp' instance"
+            )
+
         return self._app
 
     @app.setter
@@ -99,9 +122,9 @@ class Plugin:
         self.create_commands()
 
     @property
-    def bot(self) -> t.Optional[app_.BotApp]:
+    def bot(self) -> app_.BotApp:
         """Alias for :obj:`~Plugin.app`"""
-        return self._app
+        return self.app
 
     @property
     def raw_commands(self) -> t.List[commands.base.CommandLike]:
@@ -137,6 +160,14 @@ class Plugin:
                 cmd.plugin = self
                 self._all_commands.append(cmd)
 
+    @t.overload
+    def command(self, cmd_like: commands.base.CommandLike) -> commands.base.CommandLike:
+        ...
+
+    @t.overload
+    def command(self) -> t.Callable[[commands.base.CommandLike], commands.base.CommandLike]:
+        ...
+
     def command(
         self, cmd_like: t.Optional[commands.base.CommandLike] = None
     ) -> t.Union[commands.base.CommandLike, t.Callable[[commands.base.CommandLike], commands.base.CommandLike]]:
@@ -155,24 +186,29 @@ class Plugin:
 
         return decorate
 
+    @t.overload
+    def listener(self, event: t.Type[hikari.Event], listener_func: ListenerT, *, bind: bool = False) -> ListenerT:
+        ...
+
+    @t.overload
+    def listener(self, event: t.Type[hikari.Event], *, bind: bool = False) -> t.Callable[[ListenerT], ListenerT]:
+        ...
+
     def listener(
         self,
         event: t.Type[hikari.Event],
-        listener_func: t.Optional[t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, None]]] = None,
+        listener_func: t.Optional[ListenerT] = None,
+        *,
         bind: bool = False,
-    ) -> t.Union[
-        t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, None]],
-        t.Callable[
-            [t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, None]]],
-            t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, None]],
-        ],
-    ]:
+    ) -> t.Union[ListenerT, t.Callable[[ListenerT], ListenerT]]:
         """
         Adds a listener function to the plugin. This method can be used as a second order decorator, or called
         manually with the event type and function to add to the plugin as a listener.
 
         Args:
             event (Type[:obj:`~hikari.events.base_events.Event`): Event that the listener is for.
+
+        Keyword Args:
             bind (:obj:`bool`): Whether or not to bind the listener function to the plugin. If ``True``, the
                 function will be converted into a bound method and so will be called with the plugin as the
                 first argument, and the error event as the second argument. Defaults to ``False``.
@@ -184,9 +220,7 @@ class Plugin:
             self._listeners[event].append(listener_func)
             return listener_func
 
-        def decorate(
-            func: t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, None]]
-        ) -> t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, None]]:
+        def decorate(func: ListenerT) -> ListenerT:
             # TODO - allow getting event type from type hint
             if bind:
                 func = func.__get__(self)  # type: ignore
@@ -195,22 +229,25 @@ class Plugin:
 
         return decorate
 
+    @t.overload
+    def set_error_handler(self, func: ErrorHandlerT, *, bind: bool = False) -> ErrorHandlerT:
+        ...
+
+    @t.overload
+    def set_error_handler(self, *, bind: bool = False) -> t.Callable[[ErrorHandlerT], ErrorHandlerT]:
+        ...
+
     def set_error_handler(
         self,
-        func: t.Optional[t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, t.Optional[bool]]]] = None,
+        func: t.Optional[ErrorHandlerT] = None,
+        *,
         bind: bool = False,
-    ) -> t.Union[
-        t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, t.Optional[bool]]],
-        t.Callable[
-            [t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, t.Optional[bool]]]],
-            t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, t.Optional[bool]]],
-        ],
-    ]:
+    ) -> t.Union[ErrorHandlerT, t.Callable[[ErrorHandlerT], ErrorHandlerT]]:
         """
         Sets the error handler function for the plugin. This method can be used as a second order decorator,
         or called manually with the event type and function to set the plugin's error handler to.
 
-        Args:
+        Keyword Args:
             bind (:obj:`bool`): Whether or not to bind the error handler function to the plugin. If ``True``, the
                 function will be converted into a bound method and so will be called with the plugin as the
                 first argument, and the error event as the second argument. Defaults to ``False``.
@@ -222,9 +259,7 @@ class Plugin:
             self._error_handler = func
             return func
 
-        def decorate(
-            func_: t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, t.Optional[bool]]]
-        ) -> t.Callable[[hikari.Event], t.Coroutine[t.Any, t.Any, t.Optional[bool]]]:
+        def decorate(func_: ErrorHandlerT) -> ErrorHandlerT:
             if bind:
                 func_ = func_.__get__(self)  # type: ignore
             self._error_handler = func_
@@ -232,17 +267,20 @@ class Plugin:
 
         return decorate
 
+    @t.overload
+    def remove_hook(self, func: RemoveHookT, *, bind: bool = False) -> RemoveHookT:
+        ...
+
+    @t.overload
+    def remove_hook(self, *, bind: bool = False) -> t.Callable[[RemoveHookT], RemoveHookT]:
+        ...
+
     def remove_hook(
         self,
-        func: t.Optional[t.Callable[[], t.Union[t.Coroutine[t.Any, t.Any, None], None]]] = None,
+        func: t.Optional[RemoveHookT] = None,
+        *,
         bind: bool = False,
-    ) -> t.Union[
-        t.Callable[[], t.Union[t.Coroutine[t.Any, t.Any, None], None]],
-        t.Callable[
-            [t.Callable[[], t.Union[t.Coroutine[t.Any, t.Any, None], None]]],
-            t.Callable[[], t.Union[t.Coroutine[t.Any, t.Any, None], None]],
-        ],
-    ]:
+    ) -> t.Union[RemoveHookT, t.Callable[[RemoveHookT], RemoveHookT]]:
         """
         Sets the remove hook function for the plugin. This method can be used as a second order decorator,
         or called manually with the function to set the plugin's remove hook to. The registered function will
@@ -251,7 +289,7 @@ class Plugin:
         This function will be called **after** all the members of the plugin (listeners and commands) have already
         been removed from the bot.
 
-        Args:
+        Keyword Args:
             bind (:obj:`bool`): Whether or not to bind the remove hook function to the plugin. If ``True``, the
                 function will be converted into a bound method and so will be called with the plugin as an
                 argument. Defaults to ``False``.
@@ -263,9 +301,7 @@ class Plugin:
             self._remove_hook = func
             return func
 
-        def decorate(
-            func_: t.Callable[[], t.Union[t.Coroutine[t.Any, t.Any, None], None]]
-        ) -> t.Callable[[], t.Union[t.Coroutine[t.Any, t.Any, None], None]]:
+        def decorate(func_: RemoveHookT) -> RemoveHookT:
             if bind:
                 func_ = func_.__get__(self)  # type: ignore
             self._remove_hook = func_
@@ -285,3 +321,5 @@ class Plugin:
             ``None``
         """
         self._checks.extend(checks)
+        for check in checks:
+            check.add_to_object_hook(self)
